==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/authorization/entity/MapPolicyEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapPolicyEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapPolicyEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getId();
        }
    },
    ASSOCIATED_POLICY_IDS {
        public static final String FIELD_NAME = "AssociatedPolicyIds";
        public static final String FIELD_NAME_DASHED = "associated-policy-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.addAssociatedPolicyId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T p0) {
            e.removeAssociatedPolicyId((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Set<String>) e.getAssociatedPolicyIds();
        }
    },
    CONFIGS {
        public static final String FIELD_NAME = "Configs";
        public static final String FIELD_NAME_DASHED = "configs";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, K p0) {
            e.removeConfig((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <K> String mapGet(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, K key) {
            return (String) e.getConfig((String) key);
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, K key, T value) {
            e.setConfig((String) key, (String) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Map<String,String>) e.getConfigs();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setConfigs((java.util.Map<String,String>) value);
        }
    },
    DECISION_STRATEGY {
        public static final String FIELD_NAME = "DecisionStrategy";
        public static final String FIELD_NAME_DASHED = "decision-strategy";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.DecisionStrategy.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (org.keycloak.representations.idm.authorization.DecisionStrategy) e.getDecisionStrategy();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setDecisionStrategy((org.keycloak.representations.idm.authorization.DecisionStrategy) value);
        }
    },
    DESCRIPTION {
        public static final String FIELD_NAME = "Description";
        public static final String FIELD_NAME_DASHED = "description";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setDescription((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getDescription();
        }
    },
    LOGIC {
        public static final String FIELD_NAME = "Logic";
        public static final String FIELD_NAME_DASHED = "logic";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.Logic.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setLogic((org.keycloak.representations.idm.authorization.Logic) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.Logic get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (org.keycloak.representations.idm.authorization.Logic) e.getLogic();
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getName();
        }
    },
    OWNER {
        public static final String FIELD_NAME = "Owner";
        public static final String FIELD_NAME_DASHED = "owner";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setOwner((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getOwner();
        }
    },
    RESOURCE_IDS {
        public static final String FIELD_NAME = "ResourceIds";
        public static final String FIELD_NAME_DASHED = "resource-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Set<String>) e.getResourceIds();
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.addResourceId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T p0) {
            e.removeResourceId((String) p0); return null;
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setResourceServerId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getResourceServerId();
        }
    },
    SCOPE_IDS {
        public static final String FIELD_NAME = "ScopeIds";
        public static final String FIELD_NAME_DASHED = "scope-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Set<String>) e.getScopeIds();
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T p0) {
            e.removeScopeId((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.addScopeId((String) value);
        }
    },
    TYPE {
        public static final String FIELD_NAME = "Type";
        public static final String FIELD_NAME_DASHED = "type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setType((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getType();
        }
    },
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapPolicyEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapPolicyEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapPolicyEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setId((String) value);
        }
    },
    ASSOCIATED_POLICY_IDS {
        public static final String FIELD_NAME = "AssociatedPolicyIds";
        public static final String FIELD_NAME_DASHED = "associated-policy-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Set<String>) e.getAssociatedPolicyIds();
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.addAssociatedPolicyId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T p0) {
            e.removeAssociatedPolicyId((String) p0); return null;
        }
    },
    CONFIGS {
        public static final String FIELD_NAME = "Configs";
        public static final String FIELD_NAME_DASHED = "configs";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setConfigs((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> String mapGet(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, K key) {
            return (String) e.getConfig((String) key);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Map<String,String>) e.getConfigs();
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, K key, T value) {
            e.setConfig((String) key, (String) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, K p0) {
            e.removeConfig((String) p0); return null;
        }
    },
    DECISION_STRATEGY {
        public static final String FIELD_NAME = "DecisionStrategy";
        public static final String FIELD_NAME_DASHED = "decision-strategy";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.DecisionStrategy.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setDecisionStrategy((org.keycloak.representations.idm.authorization.DecisionStrategy) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (org.keycloak.representations.idm.authorization.DecisionStrategy) e.getDecisionStrategy();
        }
    },
    DESCRIPTION {
        public static final String FIELD_NAME = "Description";
        public static final String FIELD_NAME_DASHED = "description";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setDescription((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getDescription();
        }
    },
    LOGIC {
        public static final String FIELD_NAME = "Logic";
        public static final String FIELD_NAME_DASHED = "logic";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.Logic.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setLogic((org.keycloak.representations.idm.authorization.Logic) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.Logic get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (org.keycloak.representations.idm.authorization.Logic) e.getLogic();
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setName((String) value);
        }
    },
    OWNER {
        public static final String FIELD_NAME = "Owner";
        public static final String FIELD_NAME_DASHED = "owner";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getOwner();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setOwner((String) value);
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setRealmId((String) value);
        }
    },
    RESOURCE_IDS {
        public static final String FIELD_NAME = "ResourceIds";
        public static final String FIELD_NAME_DASHED = "resource-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T p0) {
            e.removeResourceId((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Set<String>) e.getResourceIds();
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.addResourceId((String) value);
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setResourceServerId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getResourceServerId();
        }
    },
    SCOPE_IDS {
        public static final String FIELD_NAME = "ScopeIds";
        public static final String FIELD_NAME_DASHED = "scope-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T p0) {
            e.removeScopeId((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.addScopeId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (java.util.Set<String>) e.getScopeIds();
        }
    },
    TYPE {
        public static final String FIELD_NAME = "Type";
        public static final String FIELD_NAME_DASHED = "type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapPolicyEntity e) {
            return (String) e.getType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapPolicyEntity e, T value) {
            e.setType((String) value);
        }
    },
}
